/********************************************************************
	purpose:    游戏模块	
*********************************************************************/

using Log;
using ProtoBuf;
using ServerLib.StaticData;
using System;
using System.IO;
using System.Collections.Generic;

namespace StaticData {
    /// <summary>
    /// 静态数据管理
    /// </summary>
    public class StaticDataMgr {
        public StaticDataMgr() : base() { }

        private static StaticDataMgr _instance;
        public static StaticDataMgr Instance {
            get {
                if (_instance == null) _instance = new StaticDataMgr();
                return _instance;
            }
        }

        //xml配置
        public GameConfig GameCfg = new GameConfig();
        //道具
        public t_item item = new t_item();
        //滾屏公告配置表
        public t_scroll_notice scroll_notice = new t_scroll_notice();
        //邮件配置表
        public t_mail_item mail_item = new t_mail_item();
        //个人标签
        public t_selftag selfTag = new t_selftag();
        //家园系统资源配置
        public t_house_res house_res = new t_house_res();
        //房产系统房屋配置
        public t_housesys_house housesys_house = new t_housesys_house();


        /// <summary>
        /// 初始化
        /// </summary>
        /// <returns></returns>
        public bool Init() {
            if (!GameCfg.Init()) return false;

            bool bSuccess = true;
            if (!item.Init()) bSuccess = false;
            if (!mail_item.Init()) bSuccess = false;
            if (!scroll_notice.Init()) bSuccess = false;
            if (!selfTag.Init()) bSuccess = false;
            if (!house_res.Init()) bSuccess = false;
            if (!housesys_house.Init()) bSuccess = false;
            if (!bSuccess) return false;

            return true;
        }

        /// <summary>
        /// 反序列化
        /// </summary>x
        /// <param name="source"></param>
        /// <param name="r"></param>
        /// <returns></returns>
        static object protoDeserialize(Stream source, Type r) {
            return Serializer.NonGeneric.Deserialize(r, source);
        }

        public static List<object> readBin(string file) {
            return ParseNode.Parse("..\\..\\StaticData\\cfg\\cfg_" + file);
        }


        /// <summary>
        /// 读取
        /// </summary>
        /// <param name="file"></param>
        /// <param name="t"></param>
        /// <returns></returns>
        public static object readObject(string file, Type t) {
            object obj = null;

            try {
                string strFile = "..\\..\\StaticData\\" + file;
                //创建文件流
                using (FileStream fs = new FileStream(strFile, FileMode.Open, FileAccess.Read)) {
                    byte[] data = new byte[fs.Length];
                    fs.Read(data, 0, (int)fs.Length);

                    using (MemoryStream ms = new MemoryStream(data)) {
                        ms.Position = 0;
                        obj = protoDeserialize(ms, t);
                    }
                }
            }
            catch (Exception ex) {
                LogSys.Error($"[StaticData][readObject],读取二进制文件出错,exception={ex.Message}");
                return null;
            }

            return obj;
        }
    }
}
